# pfinance
Python financial mathematics library.

## Installation
### Using pip
- run `pip install pfinance`

### Building from source
- clone the repo
- run `python setup.py bdist_wheel`

## TODO list
- content:
  - adjust cost basis
  - discounted cash flow
